@@ -13,6 +13,18 @@ INVALID_CHARS = {"en": r"[^a-zA-Z]", "de": r"[^a-zA-ZäöüÄÖÜß]"}
 PERCENT_WORD = {"en": "percent", "de": "Prozent"}
 AND_WORD = {"en": "and", "de": "und"}
 
+METRIC_WORD = {
+    "en": {
+        "km/h": "kilometers per hour",
+        "mph": "miles per hour",
+        "m/s": "meters per second",
+    },
+    "de": {
+        "km/h": "Kilometer pro Stunde",
+        "mph": "Meilen pro Stunde",
+        "m/s": "Meter pro Sekunde",
+    },
+}
 
 YEAR_PRECEEDING_WORDS = {
     "en": ["in", "year", "before", "after", "since"],
@@ -77,6 +89,14 @@ class TextFormatter(BaseFormatter):
         if self.lang == "de":
             return ord(c) < 128 or c in "äöüÄÖÜß"
 
+    def contains_metric(self, word):
+        w = word.lower()
+        keys = METRIC_WORD[self.lang].keys()
+        for k in keys:
+            if w.endswith(k):
+                return k
+        return None
+
     def format_text(self, text):
         """
         a whitelisted fashion as opposed to tokenizing
@@ -98,7 +118,7 @@ class TextFormatter(BaseFormatter):
             elif c == "–":
                 c = "-"
 
-            if c == "%" or c == "&":
+            if c == "%" or c == "&" or c == "/":
                 is_valid = True
             elif (
                 c == "'"
@@ -185,13 +205,18 @@ class TextFormatter(BaseFormatter):
                 newword = word.replace("&", f" {AND_WORD.get(self.lang)} ")
                 to_append = newword.strip().split()
             elif "-" in word:
-                newword = word.replace("-", " ")
-                to_append = newword.split()
+                to_append = word.split("-")
             elif ":" in word:
-                newword = word.replace(":", " ")
                 to_append = []
-                for t in newword.split():
+                for t in word.split(":"):
                     to_append += self.n2w(t)
+            elif self.contains_metric(word):
+                k = self.contains_metric(word)
+                rep = METRIC_WORD[self.lang][k]
+                to_append = word.lower().replace(k, f" {rep}").strip().split()
+            elif "/" in word:
+                # just ignore the slash
+                to_append = word.split("/")
             elif (
                 self.lang == "en"
                 and len(word) > 2
@@ -235,16 +260,24 @@ class TextFormatter(BaseFormatter):
                         to_append = self.n2w(m.group(1)) + [m.group(2)]
 
             if to_append is None:
-                to_append = [word]
+                final_append = [word]
             else:
+                # finally check whether there is still number in to_append
+                final_append = []
+                for ta in to_append:
+                    if ta.isdigit():
+                        final_append += self.n2w(ta)
+                    else:
+                        final_append.append(self.remove_invalid_chars(ta))
+
                 change_list[word] = " ".join(
                     [
                         x.upper() if self.return_upper_case else x
-                        for x in filter(len, to_append)
+                        for x in filter(len, final_append)
                     ]
                 )
 
-            word_list += to_append
+            word_list += final_append
 
         text = " ".join(word_list)
         if self.return_upper_case:
